.. Surprise documentation master file, created by
   sphinx-quickstart on Tue Dec 29 20:08:18 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. _index:

Welcome to Surprise' documentation!
===================================

`Surprise <http://surpriselib.com>`_  is an easy-to-use Python `scikit
<https://www.scipy.org/scikits.html>`_ for recommender systems.

If you're new to `Surprise <http://surpriselib.com>`_, we invite you to take a
look at the :ref:`getting_started` guide, where you'll find a series of
tutorials illustrating all you can do with  `Surprise
<http://surpriselib.com>`_. For installation guidelines, please refer to the
`project page <http://surpriselib.com>`_.

Any kind of feedback/criticism would be greatly appreciated (software design,
documentation, improvement ideas, spelling mistakes, etc...). Please feel free
to contribute and send pull requests (see `GitHub page
<https://github.com/NicolasHug/Surprise>`_)!


.. toctree::
   :caption: User Guide
   :hidden:

   getting_started
   prediction_algorithms
   building_custom_algo
   notation_standards


.. toctree::
   :maxdepth: 2
   :caption: API Reference
   :hidden:

   prediction_algorithms_package
   similarities
   accuracy
   dataset
   evaluate
   dump
